@@ -1,6 +1,6 @@
 /*
-    Linknx high level management application
-    Copyright (C) 2007 Jean-François Meessen <jf.meessen@ouaye.net>
+    LinKNX KNX home automation platform
+    Copyright (C) 2007 Jean-François Meessen <linknx@ouaye.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -97,6 +97,8 @@ public:
     ValueObject();
     virtual ~ValueObject();
 
+    virtual void exportXml(ticpp::Element* pConfig);
+
     virtual void onWrite(const uchar* buf, int len);
     virtual void setIntValue(int value);
     virtual void setFloatValue(float value);
@@ -114,6 +116,8 @@ public:
     ScalingObject();
     virtual ~ScalingObject();
 
+    virtual void exportXml(ticpp::Element* pConfig);
+
     virtual void onWrite(const uchar* buf, int len);
     virtual void setIntValue(int value);
     virtual void setFloatValue(float value);
@@ -154,6 +158,7 @@ private:
     ObjectIdMap_t objectIdMap_m;
     static ObjectController* instance_m;
     EIBConnection *con_m;
+    std::string url_m;
 };
 
 #endif
