@@ -1,6 +1,6 @@
 /*
-    Linknx high level management application
-    Copyright (C) 2007 Jean-François Meessen <jf.meessen@ouaye.net>
+    LinKNX KNX home automation platform
+    Copyright (C) 2007 Jean-François Meessen <linknx@ouaye.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -106,6 +106,7 @@ class TimerManager : protected Thread
 {
 public:
     static TimerManager* instance();
+    static void reset() { if (instance_m) delete instance_m; };
     void addTask(TimerTask* task);
     void removeTask(TimerTask* task);
 
@@ -136,7 +137,7 @@ public:
 		int year_m;
 };
 
-class ExceptionDays : public ChangeListener
+class ExceptionDays
 {
 public:
     static ExceptionDays* instance();
@@ -146,9 +147,6 @@ public:
     void importXml(ticpp::Element* pConfig);
     void exportXml(ticpp::Element* pConfig);
 
-    virtual void onChange(Object* object);
-
-    bool isException() { return value_m; };
     bool isException(time_t time);
 
 private:
@@ -158,8 +156,6 @@ private:
     typedef std::list<DaySpec*> DaysList_t;
     DaysList_t daysList_m;
     static ExceptionDays* instance_m;
-    PeriodicTask timer_m;
-    bool value_m;
 };
 
 #endif
